import { Badge } from "@/components/ui/badge"; // Assuming shadcn badge path
import { Button } from "@/components/ui/button"; // Assuming shadcn button path
import { Card, CardDescription, CardTitle } from "@/components/ui/card"; // Assuming shadcn card path
import { ImageBaseUrl } from "@/configs/api";
import { Loader2, Trash2 } from "lucide-react"; // Using lucide-react for icons
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";

function FavoriteCard({ product, removeFavorite, loadingProductIds }: { product: any, removeFavorite: (id: string) => void, loadingProductIds: Record<string, boolean> }) {
	const locale = useLocale();
	const t = useTranslations();

	return (
		<Card key={product.id} className="flex flex-col md:flex-row overflow-hidden rounded-lg shadow-sm border border-gray-200">
			{/* Product Image Container */}
			<div className="flex-shrink-0 w-full md:w-48 h-48 md:h-auto"> {/* Fixed width on desktop, full width on mobile */}
				<Image
					src={ImageBaseUrl + product?.images?.[0]?.image_path}
					alt={product.name_en}
					width={500}
					height={500}
					className="object-cover w-full h-full" // Ensure image covers the area
				/>
			</div>

			{/* Product Details and Actions Container */}
			<div className="flex flex-col flex-grow p-4 justify-between">
				<div> {/* Top section for details */}
					<div className="flex justify-between items-start mb-1">
						<CardTitle className="text-lg font-semibold mr-2">{locale === "ar" ? product.name_ar : product.name_en}</CardTitle>
						<Badge variant="secondary" className="flex-shrink-0">{locale === "ar" ? product?.category?.name_ar : product?.category?.name_en}</Badge>
					</div>
					<CardDescription className="text-sm text-gray-600 mb-2 line-clamp-2">{locale === "ar" ? product.description_ar : product.description_en}</CardDescription>

				</div>

				{/* Bottom section for action button */}
				<div className="mt-4">
					<div className="flex justify-start gap-2">
						<span className="text-lg font-bold text-gray-800">{product?.base_price}</span>
						<Image src={"/coins/Saudi_Riyal.jpg"} alt="Saudi_Riyal" width={16} height={16} />
					</div>
					<div className="flex justify-end">
						<Button
							variant="destructive"
							size="sm"
							onClick={() => removeFavorite(product.id)}
							className="flex items-center gap-1"
							disabled={loadingProductIds[product.id]}
						>
							<Trash2 className="h-4 w-4" />
							{loadingProductIds[product.id] ? <Loader2 className="h-5 w-5 animate-spin" /> : t("Remove")}
						</Button>
					</div>
				</div>
			</div>
		</Card>
	);
}

export default FavoriteCard;
